summaryrefslogtreecommitdiffstats
path: root/ksim/library/label.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksim/library/label.cpp')
-rw-r--r--ksim/library/label.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksim/library/label.cpp b/ksim/library/label.cpp
index 32a18d8..4aa12b0 100644
--- a/ksim/library/label.cpp
+++ b/ksim/library/label.cpp
@@ -136,10 +136,10 @@ void KSim::Label::clear()
void KSim::Label::setText(const TQString &text)
{
if (text == d->text)
- return; // If the text is the same, no need to tqrepaint etc
+ return; // If the text is the same, no need to repaint etc
TQSize oldSize = sizeHint();
// set the text of our widget and tqrepaint
d->text = text;
relayoutLabel(oldSize);
}
@@ -183,13 +183,13 @@ const TQColor &KSim::Label::shadowColour() const
void KSim::Label::setConfigValues()
{
TQFont newFont = font();
- bool tqrepaint = themeLoader().current().fontColours(this,
+ bool repaint = themeLoader().current().fontColours(this,
newFont, d->mColour, d->sColour, d->showShadow);
if (font() != newFont)
setFont(newFont);
- if (tqrepaint)
+ if (repaint)
update();
}
@@ -276,13 +276,13 @@ void KSim::Label::setThemePixmap(const TQString &image)
relayoutLabel(oldSize);
}
-void KSim::Label::relayoutLabel(const TQSize &old, bool tqrepaint)
+void KSim::Label::relayoutLabel(const TQSize &old, bool repaint)
{
if (sizeHint() != old) {
updateGeometry();
}
- if (tqrepaint)
+ if (repaint)
update();
}
@@ -136,10 +136,10 @@ void KSim::Label::clear()
TQSize oldSize = sizeHint();
- // set the text of our widget and tqrepaint
+ // set the text of our widget and repaint
d->text = text;
relayoutLabel(oldSize);